Download
========

.. Image Sources:
   
   * PyPI
     Source: http://www.python.org/community/logos/
     License: http://www.python.org/psf/trademarks
   
   * OSX
     Source: IconArchive (http://www.iconarchive.com/show/papercut-social-icons-by-graphicloads/Apple-icon.html)
     Author: GraphicLoads, Papercut Social Icons
     License: Freeware
   
   * Debian
     Source: NuoveXT (http://nuovext.pwsp.net/)
     Author: Alexandre Moore (http://sa-ki.deviantart.com/)
     License: GPL v2
     File: NuoveXT/128x128/apps/debian-logo.png
   
   * Ubuntu
     Source: http://logonoid.com/ubuntu-logo/
     Not quite sure of the license, probably covered by...
     http://design.ubuntu.com/brand/ubuntu-logo
   
   * Fedora
     Source: https://en.wikipedia.org/wiki/File:Fedora_logo_and_wordmark.svg
     Author: Unknown
   
   * Red Hat
     Source: NuoveXT (http://nuovext.pwsp.net/)
     Author: Alexandre Moore (http://sa-ki.deviantart.com/)
     License: GPL v2
     File: NuoveXT/128x128/apps/fedora.png
   
   * Gentoo
     Source: https://www.gentoo.org/main/en/name-logo.xml
   
   * Arch Linux
     Source: https://en.wikipedia.org/wiki/File:Archlinux-official-fullcolour.svg
   
   * Slackware
     Source: NuoveXT (http://nuovext.pwsp.net/)
     Author: Alexandre Moore (http://sa-ki.deviantart.com/)
     License: GPL v2
     File: NuoveXT/128x128/apps/slackware.png
   
   * FreeBSD
     Source: https://en.wikipedia.org/wiki/File:Freebsd_logo.svg
     Author: Anton Gural
   
   * OpenBSD
     Source: NuoveXT (http://nuovext.pwsp.net/)
     Author: Alexandre Moore (http://sa-ki.deviantart.com/)
     License: GPL v2
     File: NuoveXT/128x128/apps/openbsd.png
   
   * NetBSD
     Source: https://www.netbsd.org/gallery/logos.html
     License: https://www.netbsd.org/about/redistribution.html
   
   * Git
     Source: https://en.wikipedia.org/wiki/File:Git-logo.svg
     Author: Jason Long
     License: CC v3 (A)
   
   * Git (Alternate)
     Source: http://www.dylanbeattie.net/git_logo/
     Author: Dylan Beattie
     License: CC v3 (A, SA)

.. list-table::
   :widths: 1 10
   :header-rows: 0

   * - .. image:: /_static/section/download/pypi.png
          :target: https://pypi.org/project/stem/

     - .. image:: /_static/label/python_package_index.png
          :target: https://pypi.org/project/stem/

       Signed releases and instructions for both Python 2.x and 3.x. You can
       easily install from its `tarball
       <https://files.pythonhosted.org/packages/7f/71/d82f4204e88be00220cc54eedb2972fd05081cb0e5ebdc537d8940b064ea/stem-1.7.1.tar.gz>`_
       (`sig
       <https://files.pythonhosted.org/packages/7f/71/d82f4204e88be00220cc54eedb2972fd05081cb0e5ebdc537d8940b064ea/stem-1.7.1.tar.gz.asc>`_),
       or with **pip**...

       ::

         % sudo easy_install pip
         % sudo pip install stem

   * - .. image:: /_static/section/download/osx.png

     - .. image:: /_static/label/osx.png

       As of OSX 10.8 the platform bundles Python 2.7 by default. This makes
       installation easy...

       ::

         % sudo easy_install pip
         % sudo pip install stem

   * - .. image:: /_static/section/download/debian.png
          :target: https://packages.debian.org/sid/python-stem

     - .. image:: /_static/label/debian.png
          :target: https://packages.debian.org/sid/python-stem

       Packages by Dererk for Debian, including `python-stem
       <https://packages.debian.org/sid/python-stem>`_ (for Python 2.x) and
       `python3-stem <https://packages.debian.org/sid/python3-stem>`_ (for
       Python 3.x).

       ::

         % sudo apt-get install python-stem

   * - .. image:: /_static/section/download/ubuntu.png
          :target: https://launchpad.net/ubuntu/+source/python-stem

     - .. image:: /_static/label/ubuntu.png
          :target: https://launchpad.net/ubuntu/+source/python-stem

       Package derived from Debian for Ubuntu.

       ::

         % sudo apt-get install python-stem

   * - .. image:: /_static/section/download/fedora.png
          :target: https://apps.fedoraproject.org/packages/python-stem

     - .. image:: /_static/label/fedora.png
          :target: https://apps.fedoraproject.org/packages/python-stem

       Packages maintained by Juan for Fedora using **dnf** or **yum**. These
       include **python-stem** (for Python 2.x), **python3-stem** (for Python
       3.x), and **python-stem-doc** (this website).

       ::

         % sudo dnf install python-stem

   * - .. image:: /_static/section/download/gentoo.png
          :target: http://packages.gentoo.org/package/net-libs/stem

     - .. image:: /_static/label/gentoo.png
          :target: http://packages.gentoo.org/package/net-libs/stem

       Package by Anthony Basile for Gentoo.

       ::

         % sudo emerge stem

   * - .. image:: /_static/section/download/archlinux.png
          :target: https://www.archlinux.org/packages/community/any/python-stem/

     - .. image:: /_static/label/archlinux.png
          :target: https://www.archlinux.org/packages/community/any/python-stem/

       Package by Sjon for `Arch Linux...

       ::

           % pacman -S python-stem

   * - .. image:: /_static/section/download/slackware.png
          :target: https://slackbuilds.org/repository/14.2/python/stem/

     - .. image:: /_static/label/slackware.png
          :target: https://slackbuilds.org/repository/14.2/python/stem/

       Package by Markus for `Slackware
       <http://slackbuilds.org/howto/>`_.

   * - .. image:: /_static/section/download/freebsd.png
          :target: http://www.freshports.org/security/py-stem/

     - .. image:: /_static/label/freebsd.png
          :target: http://www.freshports.org/security/py-stem/

       Port by Carlo for `FreeBSD
       <http://www.freebsd.org/doc/en_US.ISO8859-1/books/handbook/ports.html>`_.

       ::

           % pkg install security/py-stem

   * - .. image:: /_static/section/download/openbsd.png
          :target: http://cvsweb.openbsd.org/cgi-bin/cvsweb/ports/net/py-stem/

     - .. image:: /_static/label/openbsd.png
          :target: http://cvsweb.openbsd.org/cgi-bin/cvsweb/ports/net/py-stem/

       Port by pascal for OpenBSD.

       ::

           % pkg_add py-stem

   * - .. image:: /_static/section/download/netbsd.png
          :target: http://pkgsrc.se/net/py-stem

     - .. image:: /_static/label/netbsd.png
          :target: http://pkgsrc.se/net/py-stem

       Port by Riastradh for NetBSD.

       ::

           % pkg_add py37-stem

   * - .. image:: /_static/section/download/git.png
          :target: https://gitweb.torproject.org/stem.git

     - .. image:: /_static/label/source_repository.png
          :target: https://gitweb.torproject.org/stem.git

       For those wanting to live on the bleeding edge or contribute to Stem,
       Stem's git repository can be fetched with...

       ::

         % git clone https://git.torproject.org/stem.git

